import { createApp } from 'vue'
import { createRouter, createWebHistory } from 'vue-router'
import './style.css'
import App from './App.vue'

const router = createRouter({
    history: createWebHistory(),
    routes: [
        {
            path: '/',
            name: 'Home',
            component: () => import ('./views/Home.vue'),
        },
        {
            path: '/detail',
            name: 'Detail',
            component: () => import ('./views/Detail.vue'),
        },
        {
            path: '/about',
            name: 'About',
            component: () => import ('./views/About.vue'),
        },
        {
            path: '/list',
            name: 'List',
            component: () => import ('./views/List.vue'),
        },
        {
            path: '/login',
            name: 'Login',
            component: () => import ('./views/Login.vue'),
        },
        {
            path: '/user',
            name: 'User',
            component: () => import ('./views/User.vue'),
            meta: {
                needLogin: true, // 该页面需要登录
            },
            children: [ // 嵌套路由
                {
                    path: 'info',
                    name: 'userInfo',
                    component: import('./views/User/Info.vue'),
                },
                {
                    path: 'scores',
                    name: 'userScores',
                    component: import('./views/User/Scores.vue'),
                },
                {
                    path: 'orders',
                    name: 'userOrders',
                    component: import('./views/User/Orders.vue'),
                },
            ]
        },
    ]
})

router.beforeEach((to,from,next) => {
    // console.log(to.query);
    // 这里可以做路由拦截
    // 判断当前页面是否需要登录
    if (to.meta.needLogin) {
        if (localStorage.getItem('token')) { // 有token不需要登陆
            next();
        }else {
            next({
                name: 'Login',
            })
        }
    }else {
        next();
    }
})
createApp(App).use(router).mount('#app')
